@@ -44,6 +44,8 @@
 # Copyright (c) 2019 Nikita Sobolev <mail@sobolevn.me>
 # Copyright (c) 2019 Oisín Moran <OisinMoran@users.noreply.github.com>
 # Copyright (c) 2019 Fantix King <fantix@uchicago.edu>
+# Copyright (c) 2020 Damien Baty <damien.baty@polyconseil.fr>
+# Copyright (c) 2020 Ram Rachum <ram@rachum.com>
 # Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
 # Copyright (c) 2020 bernie gray <bfgray3@users.noreply.github.com>
 # Copyright (c) 2020 Gabriel R Sezefredo <g@briel.dev>
@@ -395,8 +397,8 @@ def report_by_type_stats(sect, stats, _):
     for node_type in ("module", "class", "method", "function"):
         try:
             total = stats[node_type]
-        except KeyError:
-            raise exceptions.EmptyReportError()
+        except KeyError as e:
+            raise exceptions.EmptyReportError() from e
         nice_stats[node_type] = {}
         if total != 0:
             try:
@@ -1133,10 +1135,13 @@ class BasicChecker(_BasicChecker):
             # If the constant node is a FunctionDef or Lambda then
             #  it may be a illicit function call due to missing parentheses
             call_inferred = None
-            if isinstance(inferred, astroid.FunctionDef):
-                call_inferred = inferred.infer_call_result()
-            elif isinstance(inferred, astroid.Lambda):
-                call_inferred = inferred.infer_call_result(node)
+            try:
+                if isinstance(inferred, astroid.FunctionDef):
+                    call_inferred = inferred.infer_call_result()
+                elif isinstance(inferred, astroid.Lambda):
+                    call_inferred = inferred.infer_call_result(node)
+            except astroid.InferenceError:
+                call_inferred = None
             if call_inferred:
                 try:
                     for inf_call in call_inferred:
