@@ -38,6 +38,7 @@
 # Copyright (c) 2019 yory8 <39745367+yory8@users.noreply.github.com>
 # Copyright (c) 2019 Federico Bond <federicobond@gmail.com>
 # Copyright (c) 2019 Pascal Corpet <pcorpet@users.noreply.github.com>
+# Copyright (c) 2020 Ram Rachum <ram@rachum.com>
 # Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
 # Copyright (c) 2020 Anubhav <35621759+anubh-v@users.noreply.github.com>
 
@@ -64,7 +65,7 @@ import astroid
 import astroid.arguments
 import astroid.context
 import astroid.nodes
-from astroid import bases, decorators, exceptions, modutils, objects
+from astroid import bases, decorators, exceptions, helpers, modutils, objects
 from astroid.interpreter import dunder_lookup
 
 from pylint.checkers import BaseChecker, utils
@@ -536,9 +537,9 @@ def _determine_callable(callable_obj):
             try:
                 # Use the last definition of __init__.
                 callable_obj = callable_obj.local_attr("__init__")[-1]
-            except exceptions.NotFoundError:
+            except exceptions.NotFoundError as e:
                 # do nothing, covered by no-init.
-                raise ValueError
+                raise ValueError from e
         else:
             callable_obj = new
 
@@ -1413,7 +1414,12 @@ accessed. Python regular expressions are accepted.",
 
         for name in kwparams:
             defval, assigned = kwparams[name]
-            if defval is None and not assigned and not has_no_context_keywords_variadic:
+            if (
+                defval is None
+                and not assigned
+                and not has_no_context_keywords_variadic
+                and not overload_function
+            ):
                 self.add_message("missing-kwoa", node=node, args=(name, callable_name))
 
     def _check_invalid_sequence_index(self, subscript: astroid.Subscript):
@@ -1715,9 +1721,18 @@ accessed. Python regular expressions are accepted.",
             return
 
         inferred = safe_infer(node.value)
+
         if inferred is None or inferred is astroid.Uninferable:
             return
 
+        if getattr(inferred, "decorators", None):
+            first_decorator = helpers.safe_infer(inferred.decorators.nodes[0])
+            if isinstance(first_decorator, astroid.ClassDef):
+                inferred = first_decorator.instantiate_class()
+            else:
+                return  # It would be better to handle function
+                # decorators, but let's start slow.
+
         if not supported_protocol(inferred):
             self.add_message(msg, args=node.value.as_string(), node=node.value)
 
