@@ -14,11 +14,9 @@ from io import TextIOWrapper
 
 import astroid
 from astroid import modutils
-from astroid.__pkginfo__ import version as astroid_version
 from astroid.builder import AstroidBuilder
 
 from pylint import checkers, config, exceptions, interfaces, reporters
-from pylint.__pkginfo__ import version
 from pylint.constants import MAIN_CHECKER_NAME, MSG_TYPES
 from pylint.lint.check_parallel import check_parallel
 from pylint.lint.report_functions import (
@@ -262,7 +260,7 @@ class PyLinter(
                 "fail-under",
                 {
                     "default": 10,
-                    "type": "int",
+                    "type": "float",
                     "metavar": "<score>",
                     "help": "Specify a score threshold to be exceeded before program exits with error.",
                 },
@@ -448,16 +446,10 @@ class PyLinter(
             "disable-msg": self.disable,
             "enable-msg": self.enable,
         }
-        full_version = "pylint %s\nastroid %s\nPython %s" % (
-            version,
-            astroid_version,
-            sys.version,
-        )
         MessagesHandlerMixIn.__init__(self)
         reporters.ReportsHandlerMixIn.__init__(self)
         super().__init__(
             usage=__doc__,
-            version=full_version,
             config_file=pylintrc or next(config.find_default_config_files(), None),
         )
         checkers.BaseTokenChecker.__init__(self)
@@ -517,8 +509,8 @@ class PyLinter(
         else:
             try:
                 reporter_class = self._load_reporter_class()
-            except (ImportError, AttributeError):
-                raise exceptions.InvalidReporterError(name)
+            except (ImportError, AttributeError) as e:
+                raise exceptions.InvalidReporterError(name) from e
             else:
                 self.set_reporter(reporter_class())
 
